@@ -1,10 +1,10 @@
 /***************************************************************************
- SocNetV: Social Network Visualizer 
- version: 1.9
+ SocNetV: Social Network Visualizer
+ version: 2.1
  Written in Qt
                          edgeweight.h  -  description
                              -------------------
-    copyright            : (C) 2005-2015 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2016 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -33,18 +33,18 @@
 class Edge;
 
 static const int TypeEdgeWeight = QGraphicsItem::UserType+5;
+static const int ZValueEdgeWeight = 80;
 
 class EdgeWeight: public QGraphicsTextItem
 {
 public:
     EdgeWeight(Edge * , int, QString);
-	void removeRefs();
-	void move(double x, double y);
+    void removeRefs();
 
-	enum { Type = UserType + 5 };
-	int type() const { return Type; }
+    enum { Type = UserType + 5 };
+    int type() const { return Type; }
 
-	~EdgeWeight();
+    ~EdgeWeight();
 private:
 };
 
