@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Network Visualizer
- version: 1.9
+ version: 2.1
  Written in Qt
  
                          graphicswidget.h  -  description
                              -------------------
-    copyright            : (C) 2005-2015 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2016 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -39,6 +39,7 @@ class NodeNumber;
 class NodeLabel;
 class Guide;
 class EdgeWeight;
+class EdgeLabel;
 
 typedef QHash<QString, Edge*> H_StrToEdge;
 typedef QHash <long int, Node*> H_NumToNode;
@@ -60,21 +61,23 @@ public:
     void selectNone();
 
     void removeItem(Edge*);
+    void removeItem(EdgeWeight *edgeWeight);
+    void removeItem(EdgeLabel *edgeLabel);
     void removeItem(Node*);
     void removeItem(NodeNumber*);
     void removeItem(NodeLabel*);
-    void nodeMoved(int, int, int);
+
+    void nodeMoved(const int &number, const int &x, const int &y);
 
     void setInitNodeColor(QString);
     void setInitLinkColor(QString);
     void setInitNodeSize(int);
     void setInitNumberDistance(int);
     void setInitLabelDistance(int);
+    void setInitZoomIndex (int);
 
     void setNumbersInsideNodes(bool);
 
-    bool setEdgeWeight(int, int, float);
-
     void setAllItemsVisibility(int, bool);
 
     void removeAllItems(int);
@@ -87,55 +90,82 @@ protected:
     void paintEvent ( QPaintEvent * event );
 
 public slots:
-    void changeRelation(int relation);
+    void relationSet(int relation);
 
-    void drawNode(	int i, int size, QString aColor,
-                    QString nColor, int nSize,
-                    QString label, QString lColor, int lSize,
-                    QPointF p,
-                    QString nodeShape,
-                    bool showLabels, bool labelIn, bool showNumbers
+    void drawNode( const int &num, const int &nodeSize,
+                   const QString &nodeShape, const QString &nodeColor,
+                   const bool &showNumbers,const bool &numberInsideNode,
+                   const QString &numberColor, const int &numberSize,
+                   const bool &showLabels, const QString &nodeLabel,
+                   const QString &labelColor, const int &labelSize,
+                   const QPointF &p
                     );
-    void eraseNode(long int doomedJim);
+    void eraseNode(const long int &number);
     void setNodeVisibility(long int, bool );	//Called from Graph via MW
-    bool setNodeColor(long int, QString);
-    bool setNodeLabel(long int , QString );
-    void openNodeContextMenu();
     void nodeClicked(Node *);
-    void moveNode(int, qreal, qreal);	//Called from Graph when creating random nets.
-    bool setNodeSize(long int, int size=0);
-    void setAllNodeSize(int size=0);
+    void moveNode(const int &num, const qreal &x, const qreal &y);	//Called from Graph when creating random nets.
 
-    void drawEdge(int, int, float, bool, bool, QString, bool);
-    void eraseEdge(int, int);
+    bool setNodeSize(const long int &nodeNumber, const int &size=0);
+    void setAllNodeSize(const int &size=0);
+
+    bool setNodeShape(const long int &nodeNumber, const QString &shape);
+    bool setNodeColor(const long int &, const QString &color);
+
+    void setNodeNumberVisibility(const bool &toggle);
+    bool setNodeNumberSize(const long int &, const int &size=0);
+    bool setNodeNumberDistance(const long int &, const int &distance=0);
+
+    void setNodeLabelsVisibility(const bool &toggle);
+    bool setNodeLabelSize(const long int &, const int &size=0);
+    bool setNodeLabel(long int , QString );
+    bool setNodeLabelDistance(const long int &, const int &distance=0);
+
+    void drawEdge(const int &source, const int &target,
+                  const float &weight,
+                  const QString &label="",
+                  const QString &color="black",
+                  const int &type=0,
+                  const bool &drawArrows=true,
+                  const bool &bezier=false,
+                  const bool &weightNumbers=false);
+    void eraseEdge(const long int &source, const long int &target);
     void setEdgeVisibility (int relation, int, int, bool);
-    void setEdgeColor(long int, long int, QString);
+    bool setEdgeUndirected(const long int &, const long int &, const float &);
+    bool setEdgeWeight(const long int &, const long int &, const float &);
+    void setEdgeLabel(const long int &, const long int&, const QString &);
+    void setEdgeColor(const long int &, const long int&, const QString &);
     void edgeClicked(Edge *);
     void openEdgeContextMenu();
+    void setEdgeWeightNumbersVisibility (const bool &toggle);
+    void setEdgeLabelsVisibility(const bool &toggle);
 
-    void changeZoom(const int value);
     void startEdge(Node *node);
-    void drawEdgeReciprocal(int, int);
-    void unmakeEdgeReciprocal(int, int);
 
     void clearGuides();
-    void addGuideCircle( int x0, int y0, int radius);
-    void addGuideHLine(int y0);
-    void zoomIn();
-    void zoomOut();
-    void rot(int angle);
+    void addGuideCircle( const double&x0, const double&y0, const double&radius);
+    void addGuideHLine(const double &y0);
+
+    void zoomIn(int level = 1);
+    void zoomOut(int level = 1);
+    void rotateLeft();
+    void rotateRight();
+    void changeMatrixScale(const int value);
+    void changeMatrixRotation(int angle);
+    void reset();
 
 signals:
-    void windowResized(int,int);
-    void userDoubleClicked(int, QPointF);
-    void userMiddleClicked(int, int, float);
+    void userDoubleClickNewNode(const QPointF &);
+    void userMiddleClicked(const int &, const int &);
+    void userClickOnEmptySpace();
     void openNodeMenu();
     void openEdgeMenu();
     void openContextMenu(const QPointF p);
-    void updateNodeCoords(int, int, int);
+    void updateNodeCoords(const int &, const int &, const int &);
     void selectedNode(Node *);
     void selectedEdge(Edge *);
-    void zoomChanged(int);
+    void zoomChanged(const int);
+    void rotationChanged(const int);
+    void resized(const int, const int);
 
 
 
@@ -143,17 +173,18 @@ private:
     H_NumToNode nodeHash;	//This is used in drawEdge() method
     H_StrToEdge edgesHash; // helper hash to easily find edges
     int m_curRelation;
-    int timerId,  layoutType, m_nodeSize, m_numberDistance, m_labelDistance;
+    int  m_nodeSize, m_numberDistance, m_labelDistance;
     double m_currentScaleFactor;
+    qreal fX,fY, factor;
     int m_currentRotationAngle;
-    int zoomIndex, markedNodeOrigSize,markedEdgeSourceOrigSize, markedEdgeTargetOrigSize;
+    int m_zoomIndex, markedNodeOrigSize,markedEdgeSourceOrigSize, markedEdgeTargetOrigSize;
     QString m_nodeLabel, m_numberColor, m_nodeColor, m_labelColor, m_linkColor;
-    bool secondDoubleClick, dynamicMovement, markedNodeExist, markedEdgeExist;
+    QString edgeName;
+    bool secondDoubleClick, markedNodeExist, markedEdgeExist;
     QGraphicsItem *moving;
-    QPointF startPoint, endPoint;
     Node *firstNode, *secondNode, *markedNode1, *markedEdgeSource;
     Node *markedEdgeTarget, *tempNode ;
-
+    bool transformationActive;
 };
 
 #endif
