@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Network Visualizer
- version: 1.9
+ version: 2.1
  Written in Qt
 
                          Guide.cpp  -  description
                              -------------------
-    copyright            : (C) 2005-2015 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2016 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -27,56 +27,88 @@
 #include "guide.h"
 #include "graphicswidget.h"
 
-Guide::Guide ( GraphicsWidget *gw, int x0, int y0, int radius ) : graphicsWidget ( gw ){
-	graphicsWidget->scene()->addItem ( this );
-	m_x0=x0;
-	m_y0=y0;
-	m_radius=radius;
-	setZValue ( 250 );
-	circle=true;
+Guide::Guide ( GraphicsWidget *gw,
+               const double &x0,
+               const double &y0,
+               const double &radius ) : graphicsWidget ( gw ){
+    graphicsWidget->scene()->addItem ( this );
+    m_radius=radius;
+    setZValue(ZValueGuide);
+    circle=true;
+    setPos(x0, y0);
 }
 
 
 
-Guide::Guide ( GraphicsWidget *gw,  int y0, int w) : graphicsWidget ( gw ){
-	graphicsWidget->scene()->addItem ( this );
-	m_y0=y0;
-	width= w;
-	setZValue ( 250 );
-	circle=false;
+Guide::Guide ( GraphicsWidget *gw,
+               const double &y0, const int &width)
+    : graphicsWidget ( gw ){
+    graphicsWidget->scene()->addItem ( this );
+    setPos(0, y0);
+    m_width= width;
+    setZValue(ZValueGuide);
+    circle=false;
 }
 
 
+
+double Guide::radius() {
+    return m_radius;
+}
+
+bool Guide::isCircle() {
+    return (circle);
+}
+
+void Guide::setCircle(const QPointF &center,
+                      const double &radius ) {
+    setPos(center);
+    m_radius=radius;
+    circle = true;
+    update();
+}
+
+void Guide::setHorizontalLine(const QPointF &origin, const int &width){
+    setPos(origin);
+    m_width= width;
+    circle=false;
+    update();
+}
+
+int Guide::width() {
+    return m_width;
+}
+
 /** Returns the bounding rectangle of the background circle*/
 QRectF Guide::boundingRect() const {
     if (circle) {
-     return QRectF ( m_x0 - m_radius-1, m_y0 - m_radius-1, m_x0 + 2 * m_radius + 1, m_y0 + 2* m_radius +1 );
-	}
-	else  {
-     return QRectF ( 1, m_y0 -1,  width, m_y0 + 1 );
-	}
+        return QRectF ( - m_radius-1,  - m_radius-1,  + 2 * m_radius + 1,  + 2* m_radius +1 );
+    }
+    else  {
+        return QRectF ( 1, -1,  m_width, + 1 );
+    }
 }
 
 
 void Guide::paint ( QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget * ){
-	Q_UNUSED(option);
-	painter->setPen ( QPen ( QColor ( "red" ), 1, Qt::DotLine ) );
-	if (circle) {
-        painter->drawEllipse ( QPoint(m_x0, m_y0), m_radius, m_radius );
-	}
-	else {
-		painter->drawLine ( 10 , m_y0, width-10 , m_y0);	
-	}
+    Q_UNUSED(option);
+    painter->setPen ( QPen ( QColor ( "red" ), 1, Qt::DotLine ) );
+    if (circle) {
+        painter->drawEllipse ( QPointF(0,0), m_radius, m_radius );
+    }
+    else {
+        painter->drawLine ( 0 , 0, m_width , 0);
+    }
 }
 
 
 
 void Guide::die (){
-	this->prepareGeometryChange();
-	this->hide();
-	this->update();
-	graphicsWidget->scene()->removeItem(this);
-	this->update();
+    this->prepareGeometryChange();
+    this->hide();
+    this->update();
+    graphicsWidget->scene()->removeItem(this);
+    this->update();
 }
 
 
