@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Network Visualizer 
- version: 1.9
+ version: 2.1
  Written in Qt
 
                         matrix  -  description
                              -------------------
-    copyright            : (C) 2005-2015 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2016 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -31,8 +31,9 @@
 #define TINY 1.0e-20
 
 #include <cstdlib>		//allows the use of RAND_MAX macro
+#include <QDebug>
 #include <QtMath>		//needed for fabs, qFloor etc
-
+#include <QTextStream>
 
 
 /**
@@ -44,7 +45,7 @@
 Matrix::Matrix (int rowDim, int colDim)  : m_rows (rowDim), m_cols(colDim) {
     row = new (nothrow) Row[ m_rows ];
     Q_CHECK_PTR( row );
-    for (register int i=0;i<m_rows; i++) {
+    for (int i=0;i<m_rows; i++) {
         row[i].resize( m_cols );
     }
 }
@@ -64,10 +65,10 @@ Matrix::Matrix(const Matrix &b) {
     m_cols=b.m_cols ;
     row = new Row[m_rows];
     Q_CHECK_PTR( row );
-    for (register int i=0;i<m_rows; i++) {
+    for (int i=0;i<m_rows; i++) {
         row[i].resize( m_cols );
     }
-    for (register int i=0; i<m_rows; i++) {
+    for (int i=0; i<m_rows; i++) {
         row[i]=b.row[i];
     }
 }
@@ -94,6 +95,7 @@ void Matrix::clear() {
     }
 }
 
+
 /**
  * @brief Matrix::resize
  * Resize this matrix to m x n
@@ -109,7 +111,7 @@ void Matrix::resize (const int m, const int n) {
     row = new (nothrow) Row [ m_rows  ];
     Q_CHECK_PTR( row );
     qDebug() << "Matrix: resize() -- resizing each row";
-    for (register int i=0;i<m_rows; i++) {
+    for (int i=0;i<m_rows; i++) {
         row[i].resize( m_cols );  // CHECK ME
     }
 }
@@ -117,6 +119,384 @@ void Matrix::resize (const int m, const int n) {
 
 
 
+/**
+ * @brief Matrix::findMinMaxValues
+ * @param maxVal
+ * @param minVal
+ */
+void Matrix::findMinMaxValues (float & maxVal, float &minVal){
+    maxVal=0;
+    minVal=RAND_MAX;
+    for (int r = 0; r < rows(); ++r) {
+        for (int c = 0; c < cols(); ++c) {
+            if ( item(r,c) > maxVal)
+                maxVal = item(r,c) ;
+            if ( item(r,c) < minVal){
+                minVal= item(r,c) ;
+            }
+        }
+    }
+}
+
+
+
+
+/**
+ * @brief Matrix::identityMatrix
+ * makes this square matrix the identity square matrix I
+ * @param dim
+ */
+void Matrix::identityMatrix(int dim) {
+    qDebug() << "Matrix: identityMatrix() -- deleting old rows";
+    clear();
+    m_rows=dim;
+    m_cols=dim;
+    row = new (nothrow) Row [m_rows];
+    Q_CHECK_PTR( row );
+    qDebug() << "Matrix: resize() -- resizing each row";
+    for (int i=0;i<m_rows; i++) {
+        row[i].resize(m_rows);
+        setItem(i,i, 1);
+    }
+}
+
+
+
+/**
+ * @brief Matrix::zeroMatrix
+ * makes this matrix the zero matrix of size mxn
+ * @param m
+ * @param n
+ */
+void Matrix::zeroMatrix(const int m, const int n) {
+    qDebug() << "Matrix:: zeroMatrix() m " << m << " n " << n;
+    clear();
+    m_rows=m;
+    m_cols=n;
+    row = new (nothrow) Row [m_rows];
+    Q_CHECK_PTR( row );
+    qDebug() << "Matrix::zeroMatrix - resizing each row";
+    for (int i=0;i<m_rows; i++) {
+        row[i].resize(m_cols);
+        setItem(i,i, 0);
+    }
+
+}
+
+
+/**
+ * @brief Matrix::item
+ * returns the (r,c) matrix element
+ * @param r
+ * @param c
+ * @return
+ */
+float Matrix::item( int r, int c ){
+    return row[r].column(c);
+}
+
+
+
+/**
+ * @brief Matrix::setItem
+ * sets the (r,c) matrix element calling the setColumn method
+ * @param r
+ * @param c
+ * @param elem
+ */
+void Matrix::setItem( const int r, const int c, const float elem ) {
+    row [ r ].setColumn(c, elem);
+}
+
+
+/**
+ * @brief Matrix::clearItem
+ * clears the (r,c) matrix element
+ * @param r
+ * @param c
+ */
+void Matrix::clearItem( int r, int c ) 	{
+    row[r].clearColumn(c);
+}
+
+
+/**
+ * @brief Matrix::edgesFrom
+ * returns the number of edges starting from r
+ * @param r
+ * @return
+ */
+int Matrix::edgesFrom(int r){
+    qDebug() << "Matrix: edgesFrom() " << r << " = "<< row[r].outEdges();
+    return row[r].outEdges();
+}
+
+
+/**
+ * @brief Matrix::edgesTo
+ * @param t
+ * @return
+ */
+int Matrix::edgesTo(const int t){
+    int m_inEdges=0;
+    for (int i = 0; i < rows(); ++i) {
+        if ( item(i, t) != 0 )
+            m_inEdges++;
+    }
+    qDebug()<< "Matrix: edgesTo() " << t << " = " << m_inEdges;
+    return m_inEdges;
+}
+
+
+/**
+ * @brief Matrix::totalEdges
+ * @return
+ */
+int Matrix::totalEdges(){
+    int m_totalEdges=0;
+    for (int r = 0; r < rows(); ++r) {
+        m_totalEdges+=edgesFrom(r);
+    }
+    qDebug() << "Matrix: totalEdges " << m_totalEdges;
+    return m_totalEdges;
+}
+
+
+/**
+ * @brief Matrix::deleteRowColumn
+ * @param erased
+ */
+void Matrix::deleteRowColumn(int erased){
+    qDebug() << "Matrix: deleteRowColumn() : "<< erased;
+    qDebug() << "Matrix: m_rows before " <<  m_rows;
+
+    --m_rows;
+    qDebug() << "Matrix: m_rows now " << m_rows << ". Resizing...";
+    for (int i=0;i<m_rows+1; i++) {
+        for (int j=0;j<m_rows+1; j++) {
+            qDebug() << "Matrix: (" <<  i << ", " << j << ")="<< item(i, j) ;
+            if ( j==erased && item(i,erased) ){
+                clearItem(i,j);
+                qDebug() << i << "  connected to " << erased << ". Clearing..." ;
+            }
+            if (i<erased && j< erased) {
+                qDebug() << "i, j < erased. Skipping. Item remains";
+            }
+            if (i<erased && j>=erased) {
+                setItem( i, j, item(i,j+1) ) ;
+                qDebug() << "case 2";
+            }
+            if (i>=erased && j<erased) {
+                setItem( i, j, item(i+1,j) ) ;
+                qDebug() <<"case 3";
+            }
+            if (i>=erased && j>=erased) {
+                setItem( i, j, item(i+1,j+1) ) ;
+                qDebug() <<"case 4";
+            }
+            if (i>=m_rows || j>=m_rows) {
+                setItem( i, j, 0) ;
+                qDebug() <<"case 5 (border)";
+            }
+            qDebug() << "Matrix: new value (" <<  i << ", " << j << ")="<< item(i, j) ;
+        }
+    }
+    for (int i=0;i<m_rows; i++)
+        row[i].updateOutEdges();
+
+}
+
+
+/**
+ * @brief Matrix::fillMatrix
+ * fills a matrix with a given value
+ * @param value
+ */
+void Matrix::fillMatrix(float value )   {
+    for (int i=0;i< rows() ; i++)
+        for (int j=0;j< cols(); j++)
+            setItem(i,j, value);
+}
+
+
+
+/**
+ * @brief Matrix::subtractFromI
+ * @return
+ */
+Matrix& Matrix::subtractFromI ()  {
+    for (int i=0;i< rows();i++)
+        for (int j=0;j<cols();j++) {
+            if (i==j)
+                setItem(i,j, 1.0 - item(i,j));
+            else
+                setItem(i,j, item(i,j));
+        }
+    return *this;
+}
+
+
+
+
+/**
+ * @brief Matrix::swapRows
+ * Swaps row A with row B of this matrix
+ * @param rowA
+ * @param rowB
+ */
+void Matrix::swapRows(int rowA,int rowB){
+    qDebug()<<"   swapRow() "<< rowA+1 << " with " << rowB+1;
+    float *tempRow = new  (nothrow) float [ rows() ];
+    Q_CHECK_PTR(tempRow);
+    for ( int j=0; j<  rows(); j++) {
+      tempRow[j] = item (rowB, j);
+      setItem ( rowB, j, item ( rowA, j ) );
+      setItem ( rowA, j,  tempRow[j] );
+      }
+    delete [] tempRow;
+}
+
+
+
+
+
+/**
+* @brief Matrix::multiplyScalar
+  * Scalar Multiplication
+  * Multiplies this by float f and returns the product matrix of the same dim
+  * Allows to use P.multiplyScalar(f)
+  * @param f
+*/
+void Matrix::multiplyScalar (const float  & f) {
+        qDebug()<< "Matrix::multiplyScalar() with f " << f;
+        for (int i=0;i< rows();i++) {
+            for (int j=0;j<cols();j++) {
+                setItem(i,j, item(i,j) * f );
+            }
+        }
+}
+
+
+/**
+ * @brief Matrix::multiplyRow
+ * Multiply every element of row A by value
+ * @param row
+ * @param value
+ */
+void Matrix::multiplyRow(int row, float value) {
+    qDebug()<<"   multiplyRow() "<< row+1 << " by value " << value;
+    for ( int j=0; j<  rows(); j++) {
+        setItem ( row, j,  value * item (row, j) );
+        qDebug()<<"   item("<< row+1 << ","<< j+1 << ") = " <<  item(row,j);
+    }
+}
+
+
+
+
+
+/**
+ * @brief Matrix::product
+ * Matrix Multiplication
+ * Allows P = a * b where P, a and b are not the same initially.
+ * Takes two matrices a and b of the same dimension
+ * and returns their product as a reference to the calling object
+ * NOTE: do not use it as B.product(A,B) because it will destroy B on the way.
+ * @param a
+ * @param b
+ * @param symmetry
+ * @return
+ */
+Matrix& Matrix::product( Matrix &a, Matrix & b, bool symmetry)  {
+    qDebug()<< "Matrix::product()";
+    for (int i=0;i< rows();i++)
+        for (int j=0;j<cols();j++) {
+            setItem(i,j,0);
+            for (int k=0;k<m_rows;k++) {
+                qDebug() << "Matrix::product() - a("<< i+1 << ","<< k+1 << ")="
+                         << a.item(i,k) << "* b("<< k+1 << ","<< j+1 << ")="
+                         << b.item(k,j)  << " gives "  << a.item(i,k)*b.item(k,j);
+                if  ( k > j && symmetry) {
+                    if (a.item(i,k)!=0 && b.item(j,k)!=0)
+                        setItem(i,j, item(i,j)+a.item(i,k)*b.item(j,k));
+                }
+                else{
+                    setItem(i,j, item(i,j)+a.item(i,k)*b.item(k,j));
+                }
+            }
+            qDebug() << "Matrix::product() - ("<< i+1 << ","<< j+1 << ") = "
+                     << item(i,j);
+        }
+    return *this;
+}
+
+
+/**
+ * @brief Matrix::productSym
+ * takes two ( N x N ) matrices (symmetric) and outputs an upper triangular matrix
+ * @param a
+ * @param b
+ * @return
+ */
+Matrix& Matrix::productSym( Matrix &a, Matrix & b)  {
+    for (int i=0;i<rows();i++)
+        for (int j=0;j<cols();j++) {
+            setItem(i,j,0);
+            if (i>=j) continue;
+            for (int k=0;k<m_rows;k++)
+                if  ( k > j ) {
+                    if (a.item(i,k)!=0 && b.item(j,k)!=0)
+                        setItem(i,j, item(i,j)+a.item(i,k)*b.item(j,k));
+                }
+                else  //k <= j  && i<j
+                    if ( i>k ) {
+                        if (a.item(k,i)!=0 && b.item(k,j)!=0)
+                            setItem(i,j, item(i,j)+a.item(k,i)*b.item(k,j));
+                        }
+                        else {
+                            if (a.item(i,k)!=0 && b.item(k,j)!=0)
+                                setItem(i,j, item(i,j)+a.item(i,k)*b.item(k,j));
+                        }
+        }
+        return *this;
+}
+
+
+/**
+ * @brief Matrix::pow
+ * @param power
+ * @param symmetry
+ * @return
+ */
+Matrix& Matrix::pow (int power, bool symmetry)  {
+    Matrix t=*this;
+    for (int k=1; k<power; k++){
+        product(*this, t, symmetry);
+    }
+    return *this;
+}
+
+
+
+/**
+ * @brief Matrix::sum
+ * Matrix addition
+ * Takes two (nxn) matrices and returns their product as a reference to this
+ * Same algorithm as operator +, just different interface.
+ * In this case, you use something like: c.sum(a,b)
+ * @param a
+ * @param b
+ * @return
+ */
+Matrix& Matrix::sum( Matrix &a, Matrix & b)  {
+    for (int i=0;i< rows();i++)
+        for (int j=0;j<cols();j++)
+            setItem(i,j, a.item(i,j)+b.item(i,j));
+    return *this;
+}
+
+
+
 /**
 * @brief Matrix::operator =
 * Assigment allows copying a matrix onto another using b=a where b,a matrices
@@ -147,17 +527,18 @@ Matrix& Matrix::operator = (Matrix & a) {
 /**
 * @brief Matrix::operator +
 * Matrix addition: +
-* Adds two matrices of the same dim and returns the sum matrix.
-* Allows to sum two matrices using c=a+b
+* Adds this matrix with b of the same dim
+* Allows a+b
 * @param a
 * @return
 */
-  Matrix& Matrix::operator +(Matrix & a) {
+  Matrix& Matrix::operator +(Matrix & b) {
       qDebug()<< "Matrix::operator addition";
-      for (register int i=0;i< rows();i++)
-          for (register int j=0;j<cols();j++)
-              setItem(i,j, item(i,j)+a.item(i,j));
+      for (int i=0;i< rows();i++)
+          for (int j=0;j<cols();j++)
+              setItem(i,j, item(i,j)+b.item(i,j));
       return *this;
+
  }
 
 
@@ -165,8 +546,13 @@ Matrix& Matrix::operator = (Matrix & a) {
 
 
 
-/**  	Outputs matrix m to a text str
-*/
+/**
+ * @brief operator <<
+ * Outputs matrix m to a text str
+ * @param os
+ * @param m
+ * @return
+ */
 QTextStream& operator <<  (QTextStream& os, Matrix& m){
     qDebug() << "Matrix: << Matrix";
     int fieldWidth = 8, newFieldWidth = 8, actorNumber=1;
@@ -174,12 +560,14 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
     m.findMinMaxValues(maxVal,minVal);
     float element;
 
+
+
     if (maxVal == -1 ||  maxVal==RAND_MAX )
-         os << " max Value = " <<  QString("\xE2\x88\x9E") << endl;
+         os << " max Value = " <<  infinity << endl;
         else
         os << " max Value = " << maxVal<< endl;
     if (minVal == -1 ||  minVal==RAND_MAX )
-         os << " min Value = " <<  QString("\xE2\x88\x9E") << endl;
+         os << " min Value = " <<  infinity << endl;
     else
         os << " min Value = " << minVal<< endl<<endl;
     if (maxVal > 999999 )
@@ -194,7 +582,7 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
         fieldWidth = 7;
 
     os << qSetFieldWidth(fieldWidth) << right <<  QString("v |");
-    for (register int r = 0; r < m.cols(); ++r) {
+    for (int r = 0; r < m.cols(); ++r) {
         newFieldWidth = fieldWidth;
         actorNumber = r+1;
         if ( actorNumber > 99999)
@@ -212,7 +600,7 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
     os<<endl;
     os.setFieldAlignment(QTextStream::AlignCenter);
     os.setPadChar('-');
-    for (register int r = 0; r < m.cols()+1; ++r) {
+    for (int r = 0; r < m.cols()+1; ++r) {
         if ( r > 99999)
             newFieldWidth = fieldWidth -6;
         else if ( r > 9999)
@@ -228,7 +616,7 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
     os << qSetFieldWidth(1) << QString("-");
     os.setPadChar(' ');
     os<<endl;
-    for (register int r = 0; r < m.rows(); ++r) {
+    for (int r = 0; r < m.rows(); ++r) {
         actorNumber = r+1;
         if ( actorNumber > 99999)
             newFieldWidth = fieldWidth -5;
@@ -243,7 +631,7 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
         else
             newFieldWidth = fieldWidth;
         os << qSetFieldWidth(newFieldWidth) << right << QString("%1 |").arg(actorNumber) ;
-        for (register int c = 0; c < m.cols(); ++c) {
+        for (int c = 0; c < m.cols(); ++c) {
             element = m(r,c) ;
             newFieldWidth = fieldWidth;
             if ( element == RAND_MAX )
@@ -281,7 +669,7 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
             else
                 newFieldWidth = fieldWidth;
             if ( element == -1 || element == RAND_MAX)  // we print infinity symbol instead of -1 (distances matrix).
-                os << qSetFieldWidth(newFieldWidth) << right << QString("\xE2\x88\x9E");
+                os << qSetFieldWidth(newFieldWidth) << right << infinity;
             else
                 os << qSetFieldWidth(newFieldWidth)
                    << right << element;
@@ -292,267 +680,33 @@ QTextStream& operator <<  (QTextStream& os, Matrix& m){
 }
 
 
-void Matrix::findMinMaxValues (float & maxVal, float &minVal){
-    maxVal=0;
-    minVal=RAND_MAX;
-    for (register int r = 0; r < rows(); ++r) {
-        for (register int c = 0; c < cols(); ++c) {
-            if ( item(r,c) > maxVal)
-                maxVal = item(r,c) ;
-            if ( item(r,c) < minVal){
-                minVal= item(r,c) ;
+
+
+/**
+ * @brief Matrix::printMatrixConsole
+ * @return
+ */
+bool Matrix::printMatrixConsole(bool debug){
+    qDebug() << "Matrix::printMatrixConsole() debug " << debug ;
+    for (int r = 0; r < rows(); ++r) {
+        for (int c = 0; c < cols(); ++c) {
+            if ( item(r,c) < RAND_MAX  ) {
+                QTextStream( (debug ? stderr : stdout) ) << item(r,c) << ' ';
             }
+            else {
+                QTextStream( (debug ? stderr : stdout) ) << "X" << ' ';
+            }
+
+//            QTextStream( (debug ? stderr : stdout) )
+//                    << ( (item(r,c) < RAND_MAX ) ? item(r,c) : INFINITY  )<<' ';
         }
-    }
-}
-
-
-
-// makes this square matrix the identity square matrix I
-void Matrix::identityMatrix(int dim) {
-    qDebug() << "Matrix: identityMatrix() -- deleting old rows";
-    clear();
-    m_rows=dim;
-    m_cols=dim;
-    row = new (nothrow) Row [m_rows];
-    Q_CHECK_PTR( row );
-    qDebug() << "Matrix: resize() -- resizing each row";
-    for (int i=0;i<m_rows; i++) {
-        row[i].resize(m_rows);
-        setItem(i,i, 1);
-    }
-}
-
-
-// makes this matrix the zero matrix of size mxn
-void Matrix::zeroMatrix(const int m, const int n) {
-    qDebug() << "Matrix:: zeroMatrix() m " << m << " n " << n;
-    clear();
-    m_rows=m;
-    m_cols=n;
-    row = new (nothrow) Row [m_rows];
-    Q_CHECK_PTR( row );
-    qDebug() << "Matrix::zeroMatrix - resizing each row";
-    for (int i=0;i<m_rows; i++) {
-        row[i].resize(m_cols);
-        setItem(i,i, 0);
-    }
-
-}
-
-// returns the (r,c) matrix element
-float Matrix::item( int r, int c ){
-    return row[r].column(c);
-}
-
-// sets the (r,c) matrix element calling the setColumn method
-void Matrix::setItem( const int r, const int c, const float elem ) {
-    row [ r ].setColumn(c, elem);
-}
-
-// clears the (r,c) matrix element
-void Matrix::clearItem( int r, int c ) 	{
-	row[r].clearColumn(c); 
-}
-
-
-//returns the number of edges starting from r
-int Matrix::edgesFrom(int r){
-    qDebug() << "Matrix: edgesFrom() " << r << " = "<< row[r].outEdges();
-    return row[r].outEdges();
-}
-
-
-int Matrix::edgesTo(const int t){
-    int m_inEdges=0;
-    for (register int i = 0; i < rows(); ++i) {
-        if ( item(i, t) != 0 )
-            m_inEdges++;
-    }
-    qDebug()<< "Matrix: edgesTo() " << t << " = " << m_inEdges;
-    return m_inEdges;
-}
-
-
-int Matrix::totalEdges(){
-    int m_totalEdges=0;
-    for (register int r = 0; r < rows(); ++r) {
-        m_totalEdges+=edgesFrom(r);
-    }
-    qDebug() << "Matrix: totalEdges " << m_totalEdges;
-    return m_totalEdges;
-}
-
-
-bool Matrix::printMatrixConsole(){
-    qDebug() << "Matrix: printMatrixConsole";
-    for (register int r = 0; r < rows(); ++r) {
-        for (register int c = 0; c < cols(); ++c)
-            QTextStream(stdout) << item(r,c) <<' ';
-        QTextStream(stdout) <<'\n';
+        QTextStream( (debug ? stderr : stdout)  ) <<'\n';
     }
     return true;
 }
 
 
 
-void Matrix::deleteRowColumn(int erased){
-    qDebug() << "Matrix: deleteRowColumn() : "<< erased;
-    qDebug() << "Matrix: m_rows before " <<  m_rows;
-
-    --m_rows;
-    qDebug() << "Matrix: m_rows now " << m_rows << ". Resizing...";
-    for (register int i=0;i<m_rows+1; i++) {
-        for (register int j=0;j<m_rows+1; j++) {
-            qDebug() << "Matrix: (" <<  i << ", " << j << ")="<< item(i, j) ;
-            if ( j==erased && item(i,erased) ){
-                clearItem(i,j);
-                qDebug() << i << "  connected to " << erased << ". Clearing..." ;
-            }
-            if (i<erased && j< erased) {
-                qDebug() << "i, j < erased. Skipping. Item remains";
-            }
-            if (i<erased && j>=erased) {
-                setItem( i, j, item(i,j+1) ) ;
-                qDebug() << "case 2";
-            }
-            if (i>=erased && j<erased) {
-                setItem( i, j, item(i+1,j) ) ;
-                qDebug() <<"case 3";
-            }
-            if (i>=erased && j>=erased) {
-                setItem( i, j, item(i+1,j+1) ) ;
-                qDebug() <<"case 4";
-            }
-            if (i>=m_rows || j>=m_rows) {
-                setItem( i, j, 0) ;
-                qDebug() <<"case 5 (border)";
-            }
-            qDebug() << "Matrix: new value (" <<  i << ", " << j << ")="<< item(i, j) ;
-        }
-    }
-    for (register int i=0;i<m_rows; i++)
-        row[i].updateOutEdges();
-
-}
-
-
-/**
- * @brief Matrix::fillMatrix
- * fills a matrix with a given value
- * @param value
- */
-void Matrix::fillMatrix(float value )   {
-    for (int i=0;i< rows() ; i++)
-        for (int j=0;j< cols(); j++)
-            setItem(i,j, value);
-}
-
-// takes two matrices of the same size and returns their product as a reference to the calling object
-// Beware: do not use it as B.product(A,B) because it will destroy B on the way.
-Matrix& Matrix::product( Matrix &a, Matrix & b, bool symmetry)  {
-    qDebug()<< "Matrix::product()";
-    for (register int i=0;i< rows();i++)
-        for (register int j=0;j<cols();j++) {
-            setItem(i,j,0);
-            for (register int k=0;k<m_rows;k++) {
-                qDebug() << "Matrix::product() - a("<< i+1 << ","<< k+1 << ")="
-                         << a.item(i,k) << "* b("<< k+1 << ","<< j+1 << ")="
-                         << b.item(k,j)  << " gives "  << a.item(i,k)*b.item(k,j);
-                if  ( k > j && symmetry) {
-                    if (a.item(i,k)!=0 && b.item(j,k)!=0)
-                        setItem(i,j, item(i,j)+a.item(i,k)*b.item(j,k));
-                }
-                else{
-                    setItem(i,j, item(i,j)+a.item(i,k)*b.item(k,j));
-                }
-            }
-            qDebug() << "Matrix::product() - ("<< i+1 << ","<< j+1 << ") = "
-                     << item(i,j);
-        }
-    return *this;
-}
-		
-//takes two ( N x N ) matrices (symmetric) and outputs an upper triangular matrix
-Matrix& Matrix::productSym( Matrix &a, Matrix & b)  {
-    for (register int i=0;i<rows();i++)
-        for (register int j=0;j<cols();j++) {
-			setItem(i,j,0);
-			if (i>=j) continue;
-            for (register int k=0;k<m_rows;k++)
-				if  ( k > j ) {
-					if (a.item(i,k)!=0 && b.item(j,k)!=0)
-						setItem(i,j, item(i,j)+a.item(i,k)*b.item(j,k));
-				}
-				else  //k <= j  && i<j
-					if ( i>k ) {
-						if (a.item(k,i)!=0 && b.item(k,j)!=0)
-							setItem(i,j, item(i,j)+a.item(k,i)*b.item(k,j));
-						}
-						else {
-							if (a.item(i,k)!=0 && b.item(k,j)!=0)
-								setItem(i,j, item(i,j)+a.item(i,k)*b.item(k,j));
-						}
-	    }
-	    return *this;
-}
-	
-Matrix& Matrix::pow (int power, bool symmetry)  {
-	Matrix t=*this;
-	for (register int k=1; k<power; k++){
-		product(*this, t, symmetry);
-	}
-	return *this;
-}
-
-
-//takes two (nxn) matrices and returns their product as a reference to this
-Matrix& Matrix::sum( Matrix &a, Matrix & b)  {
-	for (register int i=0;i< rows();i++)
-		for (register int j=0;j<cols();j++)
-		    setItem(i,j, a.item(i,j)*b.item(i,j));
-	return *this;
-}
-
-
-
-Matrix& Matrix::subtractFromI ()  {
-    for (register int i=0;i< rows();i++)
-        for (register int j=0;j<cols();j++) {
-            if (i==j)
-                setItem(i,j, 1.0 - item(i,j));
-            else
-                setItem(i,j, item(i,j));
-        }
-    return *this;
-}
-
-
-/* Swaps row A with row B of this matrix */
-void Matrix::swapRows(int rowA,int rowB){
-    qDebug()<<"   swapRow() "<< rowA+1 << " with " << rowB+1;
-    float *tempRow = new  (nothrow) float [ rows() ];
-    Q_CHECK_PTR(tempRow);
-    for ( register int j=0; j<  rows(); j++) {
-	  tempRow[j] = item (rowB, j);
-	  setItem ( rowB, j, item ( rowA, j ) );
-	  setItem ( rowA, j,  tempRow[j] );
-      }
-    delete [] tempRow;
-}
-
-
-
-
-/* Multiply every element of row A by value */
-void Matrix::multiplyRow(int row, float value) {
-    qDebug()<<"   multiplyRow() "<< row+1 << " by value " << value;
-    for ( register int j=0; j<  rows(); j++) {
-        setItem ( row, j,  value * item (row, j) );
-        qDebug()<<"   item("<< row+1 << ","<< j+1 << ") = " <<  item(row,j);
-    }
-}
-
 
 
 
@@ -577,13 +731,13 @@ Matrix& Matrix::inverseByGaussJordanElimination(Matrix &A){
 	int l=0, m_pivotLine=0;
 	float m_pivot=0, temp_pivot=0, elim_coef=0;
 
-	for ( register int j=0; j< n; j++) { // for n, it is the last diagonal element of A
+    for ( int j=0; j< n; j++) { // for n, it is the last diagonal element of A
 	    l=j+1;
 	    m_pivotLine=-1;
 	    m_pivot = A.item(j,j);
 	    qDebug() << "inverseByGaussJordanElimination() at column " << j+1
 		    << " Initial pivot " << m_pivot ;
-        for ( register int i=l; i<n; i++) {
+        for ( int i=l; i<n; i++) {
             temp_pivot = A.item(i,j);
             if ( qFabs( temp_pivot ) > qFabs ( m_pivot ) ) {
                 qDebug() << " A("<< i+1 << ","<< j+1  << ") = " <<  temp_pivot
@@ -600,7 +754,7 @@ Matrix& Matrix::inverseByGaussJordanElimination(Matrix &A){
 
 
 	    qDebug()<<"   multiplyRow() "<< j+1 << " by value " << 1/m_pivot ;
-        for ( register int k=0; k<  rows(); k++) {
+        for ( int k=0; k<  rows(); k++) {
             A.setItem ( j, k,  (1/m_pivot) * A.item (j, k) );
             setItem ( j, k,  (1/m_pivot) * item (j, k) );
             qDebug()<<"   A.item("<< j+1 << ","<< k+1 << ") = " <<  A.item(j,k);
@@ -608,7 +762,7 @@ Matrix& Matrix::inverseByGaussJordanElimination(Matrix &A){
         }
 
 	    qDebug() << "eliminate variables FromRowsBelow()" << j+1 ;
-	    for ( register int i=0; i<  rows(); i++) {
+        for ( int i=0; i<  rows(); i++) {
 		 qDebug()<<"   Eliminating item("<< i+1 << ","<< j+1 << ") = "
 			 <<  A.item(i,j) << " while at column j="<<j+1;
 		 if ( A.item(i,j)==0 ){
@@ -620,7 +774,7 @@ Matrix& Matrix::inverseByGaussJordanElimination(Matrix &A){
 		    continue;
 		}
 		elim_coef=A.item (i, j);
-		for ( register int k=0; k<  cols(); k++) {
+        for ( int k=0; k<  cols(); k++) {
 		    qDebug()<<"   A.item("<< i+1 << ","<< k+1 << ") = " <<  A.item(i,k)
 			    << " will be subtracted by " << " A.item ("<< i+1
 			    << ", "<< j+1 << ") x A.item(" << j+1 << ","<<k+1
@@ -814,6 +968,11 @@ void Matrix::lubksb(Matrix &a, const int &n, int indx[], float b[])
     }
 }
 
+/**
+ * @brief Matrix::inverse
+ * @param a
+ * @return
+ */
 Matrix& Matrix::inverse(Matrix &a)
 {
     int i,j, n=a.rows();
