@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Network Visualizer
- version: 1.9
+ version: 2.1
  Written in Qt
  
                          webcrawler.cpp  -  description
                              -------------------
-    copyright            : (C) 2005-2015 by Dimitris B. Kalamaras
+    copyright            : (C) 2005-2016 by Dimitris B. Kalamaras
     email                : dimitris.kalamaras@gmail.com
  ***************************************************************************/
 
@@ -472,7 +472,7 @@ void WebCrawler_Parser::newLink(int s, QUrl target,  bool enqueue_to_frontier) {
 
     m_discoveredNodes++;
     knownUrls[target]=m_discoveredNodes;
-    emit signalCreateNode( target.toString(), m_discoveredNodes);
+    emit signalCreateNode( m_discoveredNodes, target.toString(), false);
     qDebug()<< "**   wc_parser::newLink(): Creating node " << m_discoveredNodes
             << " url "<< target.toString();
 
